Changelog
============


1.1.2 (2023-09-03)
------------

Changed
~~~~~~~~~~~~

* Improving documentation. [Luis Alejandro Martínez Faneyth]


1.1.1 (2023-09-01)
------------

Changed
~~~~~~~~~~~~

* Improving versioning workflow. [Luis Alejandro Martínez Faneyth]

* Improving pipeline. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Adding placeholder for github actions documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Fixing functional tests. [Luis Alejandro Martínez Faneyth]


1.1.0 (2023-08-31)
------------

Changed
~~~~~~~~~~~~

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Rewriting linkedin module to use official api. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* Test. [Luis Alejandro Martínez Faneyth]


1.0.1 (2023-08-30)
------------

Changed
~~~~~~~~~~~~

* Improving linkedin authentication. [Luis Alejandro Martínez Faneyth]

* Fixing test. [Luis Alejandro Martínez Faneyth]


1.0.0 (2023-08-29)
------------

Changed
~~~~~~~~~~~~

* Updating version. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Removing support for python 3.8. [Luis Alejandro Martínez Faneyth]

* Improving reliability of scripts. [Luis Alejandro Martínez Faneyth]

* Downgrading coverage because coveralls doesnt support version 7 yet. [Luis Alejandro Martínez Faneyth]

* Adding functiona; tests. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Completing LinkedIn functionality. Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Improving documentation. [Luis Alejandro Martínez Faneyth]

* Fixing PR workflow. [Luis Alejandro Martínez Faneyth]

* Developing functions. [Luis Alejandro Martínez Faneyth]

* Changing name to Agora. [Luis Alejandro Martínez Faneyth]

* Developing Instagram and LinkedIn actions. [Luis Alejandro Martínez Faneyth]

* Adding basic functionalities. [Luis Alejandro Martínez Faneyth]


Fixed
~~~~~~~~~~~~

* Allowing python 3.11 build to fail without failing entire workflow, also on PRs. [Luis Alejandro Martínez Faneyth]

* Allowing python 3.11 build to fail without failing entire workflow. [Luis Alejandro Martínez Faneyth]


Other
~~~~~~~~~~~~

* Update requirements.txt. [Luis Alejandro]

* Initial commit. [Luis Alejandro Martínez Faneyth]

